# -*- coding: utf-8 -*-
"""
Created on Thu Oct 23 23:18:04 2014

@author: henri
"""
from __future__ import division
import matplotlib.pyplot as plt
import numpy as np
from matplotlib import animation
from matplotlib.widgets import Slider


lamba = 1
f = 1

k = 2*np.pi / lamba
w = 2*np.pi * f
delta = 2.
dt = 0.01

xmin = 0
xmax = 6
nbx = 500

x = np.linspace(xmin, xmax, nbx)
x0 = [0., delta/2, delta, 3/2*delta]

fig = plt.figure() # initialise la figure

line, = plt.plot([],[],linewidth=3.0,color='red',\
label = r'$S_1 e^{-x/\delta}\cos (kx-\omega t)$')

line0, = plt.plot([],[],'o', color = 'green', ms = 10) #points verts qui se déplacent
line1, = plt.plot([],[],'o', color = 'blue', ms = 10) #points bleux qui se déplacent
line2, = plt.plot([],[],'o', color = 'black', ms = 15) #point qui suit l'onde
ax = plt.gca()
ax.spines['bottom'].set_position(('data',0)) #définit la position de l'axe des x
l1, = plt.plot([],[],linewidth=2.0,color='black') #deux enveloppes
l2, = plt.plot([],[],linewidth=2.0,color='black')
#plt.plot([0,xmax],[0,0],color = 'black', linewidth=1) #axe horizontal
l3, = plt.plot([],[],'--',color='black') #tangentes à l'origine
l4, = plt.plot([],[],'--',color='black')
ax.xaxis.set_label_coords(1.05, 0.55)
ax.set_xlabel('$z$', fontsize = 16)
for label in ax.get_xticklabels() + ax.get_yticklabels() :
    label.set_fontsize(16)
    label.set_bbox(dict(facecolor='white', edgecolor='None', alpha=0.65 ))

plt.xticks([i*delta for i in range(8)], [r'$%i\delta_0$' %i if i>1 else r'$\delta_0$' if i == 1 \
else '$0$' for i in range(8)], size=16)
plt.legend(loc='upper right')
y_ticks = [-1, 0, +1]
plt.yticks(y_ticks,['$-S_1$','$0$', '$S_1$'])

plt.xlim(xmin, xmax)
plt.ylim(-1.1, 1.1)

x0 = np.array([i*2*np.pi/k for i in range(8)])
x1 = np.array([(i+0.5)*2*np.pi/k for i in range(7)])
l5, = plt.plot([],[],'o-',color='green', linewidth = 2.)
l6, = plt.plot([],[],'o-',color='blue', linewidth = 2.)


# fonction à définir quand blit=True
# crée l'arrière de l'animation qui sera présent sur chaque image
def init():
    line.set_data([],[])
    line0.set_data([],[])
    line1.set_data([],[])
    line2.set_data([],[])
    return line,line0,line1,line2,

pause = False

def simData():
    t_max = 6.
    t = 0.0
    while t < t_max:
        if not pause:
            t = t + dt
        yield t

def onClick(event):
    global pause
    if event.inaxes==ax:
        pause ^= True    

def animate(simData): 
    t = simData
    y = np.cos(k*x - w*t)*np.exp(-x/delta)
    line.set_data(x, y)
    y0 = np.cos(k*x0 - w*t)*np.exp(-x0/delta)
    y1 = np.cos(k*x1 - w*t)*np.exp(-x1/delta)
    line0.set_data(x0, y0)
    line1.set_data(x1, y1)
    
    xj = w*t/k
    yj = np.cos(k*xj - w*t)*np.exp(-xj/delta)
    line2.set_data([xj], [yj])
    l1.set_data(x,np.exp(-x/delta))
    l2.set_data(x,-np.exp(-x/delta))
    l3.set_data([0, delta],[1,0])
    l4.set_data([0, delta],[-1,0])
    l5.set_data([x0[1],x0[1]],[-np.exp(-x0[1]/delta), np.exp(-x0[1]/delta)])
    l6.set_data([x1[0],x1[0]],[-np.exp(-x1[0]/delta), np.exp(-x1[0]/delta)])
    
    time_text.set_text(time_template%(t))
    return line,line0,line1,line2,l1,l2,l3,l4,l5,l6,time_text

def update(val):
    global delta
    delta = slider_delta.val
    

def update_vitesse(val):
    global dt
    dt = slider_vitesse.val/5*0.01

axcolor = 'lightgoldenrodyellow'
axdelta = plt.axes([0.07, 0.05, 0.2, 0.015], facecolor=axcolor)
axvitesse = plt.axes([0.5, 0.05, 0.3, 0.015], facecolor=axcolor)
slider_delta = Slider(axdelta, r'$\delta : $', 0, 5, valinit = delta, valfmt = '%.1f $m$')
slider_vitesse = Slider(axvitesse, 'vitesse : ', 1, 10, valinit = 5, valfmt = '%i')

time_template = 'Time = %.1f $T$'    # prints running simulation time
time_text = ax.text(0.75, 0.1, '', transform=ax.transAxes)
slider_delta.on_changed(update)
slider_vitesse.on_changed(update_vitesse)

fig.canvas.mpl_connect('button_press_event', onClick)
ani = animation.FuncAnimation(fig, animate, simData, init_func=init, blit=True, interval=10, repeat=True)

plt.show()